OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" karpetan!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Hau normalean konpon daiteke web zerbitzariari konfigurazio direktoriorako idazteko sarbidea emanez.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Bestela, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri bertan \"config_is_read_only\" aukerari 'egia' balioa.",
    "See %s" : "Ikusi %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "%1$s aplikazioa ez dago edo zerbitzari honekiko bertsio bateraezina du. Mesedez egiaztatu aplikazioen karpeta.",
    "Sample configuration detected" : "Adibide-ezarpena detektatua",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Adibide-ezarpena kopiatu dela detektatu da. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
    "The page could not be found on the server." : "Orria ez da zerbitzarian aurkitu.",
    "%s email verification" : "%sposta elektronikoaren egiaztapena",
    "Email verification" : "Posta elektronikoaren egiaztapena",
    "Click the following button to confirm your email." : "Egin klik hurrengo botoian zure posta elektronikoa berresteko.",
    "Click the following link to confirm your email." : "Egin klik esteka honetan zure posta elektronikoa berresteko.",
    "Confirm your email" : "Berretsi zure posta elektronikoa",
    "Other activities" : "Beste jarduerak",
    "%1$s and %2$s" : "%1$s eta %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s eta %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s eta %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s eta %5$s",
    "Education bundle" : "Hezkuntza bilduma",
    "Enterprise bundle" : "Enpresa multzoa",
    "Groupware bundle" : "Talderanerako multzoa",
    "Hub bundle" : "Hub sorta",
    "Public sector bundle" : "Sektore publikoko sorta",
    "Social sharing bundle" : "Partekatze sozial multzoa",
    "PHP %s or higher is required." : "PHP %s edo berriagoa behar da.",
    "PHP with a version lower than %s is required." : "PHPren bertsioa %s baino txikiagoa izan behar da.",
    "%sbit or higher PHP required." : "%sbiteko edo PHP bertsio berriagoa behar da. ",
    "The following architectures are supported: %s" : "Hurrengo arkitekturak onartzen dira: %s",
    "The following databases are supported: %s" : "Hurrengo datu-baseak onartzen dira: %s",
    "The command line tool %s could not be found" : "Komando lerroko %s tresna ezin da aurkitu",
    "The library %s is not available." : "%s liburutegia ez dago eskuragarri.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$sliburutegiaren %2$s bertsioa baino berriagoa behar da - %3$s bertsioa eskuragarri.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s liburutegiaren %2$sbertsioa baino txikiagoa behar da - %3$s bertsioa eskuragarri.",
    "The following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
    "Server version %s or higher is required." : "Zerbitzariaren %s bertsioa edo berriagoa behar da.",
    "Server version %s or lower is required." : "Zerbitzariaren %s bertsioa edo zaharragoa behar da.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako kontua administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
    "Logged in account must be an admin or sub admin" : "Saioa hasitako kontua administratzaile edo azpi-administratzailea izan behar du",
    "Logged in account must be an admin" : "Saioa hasitako kontua administratzailea izan behar du",
    "Wiping of device %s has started" : "%s gailuaren garbiketa hasi da",
    "Wiping of device »%s« has started" : "»%s« gailuaren garbiketa hasi da",
    "»%s« started remote wipe" : "»%s«(e)k urruneko garbiketa hasi du",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "»%s« gailuak edo aplikazioak urruneko garbiketa prozesua hasi du. Prozesua amaitutakoan beste mezu elektroniko bat jasoko duzu",
    "Wiping of device %s has finished" : "%s gailuaren garbiketa amaitu da",
    "Wiping of device »%s« has finished" : "»%s« gailuaren garbiketa amaitu da",
    "»%s« finished remote wipe" : "»%s«(e)k urruneko garbiketa amaitu du",
    "Device or application »%s« has finished the remote wipe process." : "»%s« gailuak edo aplikazioak urruneko garbiketa prozesua amaitu du.",
    "Remote wipe started" : "Urruneko garbiketa hasi da",
    "A remote wipe was started on device %s" : "Urruneko garbiketa hasi da %s gailuan",
    "Remote wipe finished" : "Urruneko garbiketa bukatu da",
    "The remote wipe on %s has finished" : "Urruneko garbiketa amaitu da %s(e)n",
    "Authentication" : "Autentifikazioa",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "Avatar image is not square" : "Abatarreko irudia ez da karratua",
    "Files" : "Fitxategiak",
    "View profile" : "Ikusi profila",
    "_%nh_::_%nh_" : ["%nh","%nh"],
    "Local time: %s" : "Ordu lokala: %s",
    "today" : "gaur",
    "tomorrow" : "bihar",
    "yesterday" : "atzo",
    "_in %n day_::_in %n days_" : ["egun %nean","%n egunetan"],
    "_%n day ago_::_%n days ago_" : ["orain dela egun %n","orain dela %n egun"],
    "next month" : "datorren hilabetea",
    "last month" : "joan den hilabetean",
    "_in %n month_::_in %n months_" : ["hilabete %nean","%n hilabete barru"],
    "_%n month ago_::_%n months ago_" : ["orain dela hilabete %n","orain dela %n hilabete"],
    "next year" : "datorren urtean",
    "last year" : "joan den urtean",
    "_in %n year_::_in %n years_" : ["urte %nean","%n urte barru"],
    "_%n year ago_::_%n years ago_" : ["orain dela urte %n","orain dela %n urte"],
    "_in %n hour_::_in %n hours_" : ["ordu %n barru","%n ordu barru"],
    "_%n hour ago_::_%n hours ago_" : ["orain dela ordu %n","orain dela %n ordu"],
    "_in %n minute_::_in %n minutes_" : ["minutu %nean","%n minutu barru"],
    "_%n minute ago_::_%n minutes ago_" : ["orain dela minutu %n","orain dela %n minutu"],
    "in a few seconds" : "segundo gutxitan",
    "seconds ago" : "duela segundo batzuk",
    "Empty file" : "Fitxategi hutsa",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s IDa duen modulua ez da existitzen. Gaitu zure aplikazioen ezarpenetan edo jarri harremanetan administratzailearekin.",
    "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" debekatutako fitxategi edo karpeta-izen bat da.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" debekatutako aurrizkia da fitxategi edo karpeten izenetarako.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ez da onartzen fitxategi edo karpeta-izen baten barruan.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" debekatutako fitxategi mota bat da.",
    "Filenames must not end with \"%1$s\"." : "Fitxategi-izenak ez dira \"%1$s\"rekin amaitu behar.",
    "Invalid parent path" : "Guraso bide-izen baliogabea",
    "File already exists" : "Badago izen bereko fitxategi bat",
    "Invalid path" : "Bide-izen baliogabea",
    "Failed to create file from template" : "Fitxategi berria txantiloitik sortzeak huts egin du",
    "Templates" : "Txantiloiak",
    "Storage %s cannot be moved" : "%s biltegia ezin da mugitu",
    "Moving a share (%s) into a shared folder is not allowed" : "Partekatze bat (%s) partekatutako karpeta batera mugitzea ez dago baimenduta",
    "Moving a storage (%s) into a shared folder is not allowed" : "Biltegi bat (%s) partekatutako karpeta batera mugitzea ez dago baimenduta",
    "Moving a share (%s) into another share (%s) is not allowed" : "Partekatze bat (%s) beste partekatze (%s) batera mugitzea ez dago baimenduta",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Biltegi bat (%s) beste biltegi (%s) batera mugitzea ez dago baimenduta",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Biltegi bat (%s) partekatze (%s) batera mugitzea ez dago baimenduta",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Biltegi bat (%s) beste biltegi (%s) batera mugitzea ez dago baimenduta",
    "Path contains invalid segments" : "Bideak segmentu baliogabeak ditu",
    "Filename is a reserved word" : "Fitxategi izena hitz erreserbatua da",
    "Filename contains at least one invalid character" : "Fitxategi-izenak karaktere baliogabe bat du gutxienez",
    "Filename is too long" : "Fitxategi-izena luzeegia da",
    "Empty filename is not allowed" : "Fitxategiaren izena ezin da hutsa izan",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "«%s» aplikazioa ezin da instalatu appinfo fitxategia ezin delako irakurri.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" aplikazioa ezin da instalatu ez delako zerbitzariaren bertsio honekin bateragarria.",
    "__language_name__" : "Euskara",
    "This is an automatically sent email, please do not reply." : "Hau automatikoki bidalitako mezua da, ez erantzun mesedez.",
    "Help & privacy" : "Laguntza eta pribatutasuna",
    "Appearance and accessibility" : "Itxura eta irisgarritasuna",
    "Apps" : "Aplikazioak",
    "Personal settings" : "Ezarpen pertsonalak",
    "Administration settings" : "Administrazio ezarpenak",
    "Settings" : "Ezarpenak",
    "Log out" : "Amaitu saioa",
    "Accounts" : "Kontuak",
    "Email" : "Posta elektronikoa",
    "Mail %s" : "Idatzi %s(r)i",
    "Fediverse" : "Fedibertsoa",
    "View %s on the fediverse" : "Ikusi %s fedibertsoan",
    "Phone" : "Telefonoa",
    "Call %s" : "Deitu %s(r)i",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Ikusi %s Twitterren",
    "Website" : "Webgunea",
    "Visit %s" : "Bisitatu %s",
    "Address" : "Helbidea",
    "Profile picture" : "Profil-irudia",
    "About" : "Honi buruz",
    "Display name" : "Erakusteko izena",
    "Headline" : "Izenburua",
    "Organisation" : "Erakundea",
    "Role" : "Zeregina",
    "Pronouns" : "Izenordainak",
    "Unknown account" : "Kontu ezezaguna",
    "Additional settings" : "Ezarpen gehiago",
    "Enter the database Login and name for %s" : "Sartu datu-basearen saioa eta izena %s(r)entzako",
    "Enter the database Login for %s" : "Sartu %s(r)en datu-base saioa",
    "Enter the database name for %s" : "Sartu %s(r)en datu-base izena",
    "You cannot use dots in the database name %s" : "Ezin duzu punturik erabili %s datu-base izenean",
    "MySQL Login and/or password not valid" : "MySQL saio edota pasahitza baliogabea",
    "You need to enter details of an existing account." : "Existitzen den kontu baten xehetasunak sartu behar dituzu.",
    "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
    "Oracle Login and/or password not valid" : "Oracle saio edota pasahitza baliogabea",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL saio edota pasahitza baliogabea",
    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez kontsideratu GNU/Linux zerbitzari bat erabiltzea.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da batere gomendagarria.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
    "Set an admin Login." : "Ezarri administraziorako saioa.",
    "Set an admin password." : "Ezarri administraziorako pasahitza.",
    "Cannot create or write into the data directory %s" : "Ezin da sortu edo idatzi %s datu-direktorioan ",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s partekatze motorrak OCP\\Share_Backend interfazea inplementatu behar du ",
    "Sharing backend %s not found" : "Ez da %s partekatze motorra aurkitu",
    "Sharing backend for %s not found" : "Ez da %s(e)rako partekatze motorrik aurkitu",
    "%1$s shared %2$s with you" : "%1$sk %2$s partekatu du zurekin",
    "Open %s" : "Ireki %s",
    "%1$s via %2$s" : "%2$s bidez, %1$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$serabiltzaileak %2$s partekatu du zurekin eta hau gehitu nahi du:",
    "%1$s shared %2$s with you and wants to add" : "%1$serabiltzaileak %2$s partekatu du zurekin eta hau gehitu nahi du",
    "%s added a note to a file shared with you" : "%s erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
    "Passwords are enforced for link and mail shares" : "Esteka eta posta partekatzeentzako pasahitzak behartzen dira",
    "Share recipient is not a valid user" : "Partekatzearen hartzailea ez da baliozko erabiltzailea",
    "Share recipient is not a valid group" : "Partekatzearen hartzailea ez da baliozko taldea",
    "Share recipient should be empty" : "Partekatzearen hartzailea huts egon beharko luke",
    "Share recipient should not be empty" : "Partekatzearen hartzailea ez luke huts egon beharko",
    "Share recipient is not a valid circle" : "Partekatzearen hartzailea ez da baliozko zirkulua",
    "Unknown share type" : "Partekatze mota ezezaguna",
    "Share initiator must be set" : "Partekatzearen hasieratzailea ezarri behar da",
    "Cannot share with yourself" : "Ezin duzu zurekin partekatu",
    "Shared path must be set" : "Partekatzearen bide-izena ezarri behar da",
    "Shared path must be either a file or a folder" : "Partekatzearen bide-izena fitxategi edo karpeta bat izan behar da",
    "You cannot share your root folder" : "Ezin duzu zure erro-karpeta partekatu",
    "You are not allowed to share %s" : "Ez duzu %s partekatzeko baimenik",
    "Valid permissions are required for sharing" : "Baliozko baimenak behar dira partekatzeko",
    "Cannot increase permissions of %s" : "Ezin dira %s(r)en baimenak handitu",
    "Shares need at least read permissions" : "Partekatzeak gutxienez irakurtzeko baimenak izan behar ditu",
    "Files cannot be shared with delete permissions" : "Fitxategiak ezin dira ezabatze baimenarekin partekatu",
    "Files cannot be shared with create permissions" : "Fitxategiak ezin dira sortze baimenarekin partekatu",
    "Expiration date is in the past" : "Iraungitze-data iraganean dago",
    "Expiration date is enforced" : "Iraungitze-data betearazten da",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri","Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri"],
    "Sharing is only allowed with group members" : "Taldeko kideekin bakarrik parteka daiteke",
    "Sharing %s failed, because this item is already shared with the account %s" : "%s partekatzeak huts egin du, dagoeneko %s kontuarekin partekatuta dagoelako",
    "Group sharing is now allowed" : "Talde-partekatzea baimentzen da orain",
    "Sharing is only allowed within your own groups" : "Soilik zure taldeekin partekatu dezakezu",
    "Path is already shared with this group" : "Bide-izen hau dagoeneko partekatuta dago talde honekin",
    "Link sharing is not allowed" : "Esteken partekatzea ez da onartzen",
    "Public upload is not allowed" : "Igotze publikoa ez da onartzen",
    "Sharing is disabled" : "Partekatzea desgaituta dago",
    "Sharing is disabled for you" : "Partekatzea zuretzat desgaituta dago",
    "Cannot share with the share owner" : "Ezin da partekatzearen jabearekin partekatu",
    "Share does not have a full ID" : "Partekatzeak ez dauka ID oso bat",
    "Cannot change share type" : "Ezin da partekatze mota aldatu",
    "Can only update recipient on user shares" : "Hartzailea erabiltzaile-partekatzeetan soilik eguneratu daiteke",
    "Cannot enable sending the password by Talk with an empty password" : "Ezin da gaitu Talk-en bidez pasahitza bidaltzea pasahitza hutsik badago",
    "Cannot enable sending the password by Talk without setting a new password" : "Ezin da gaitu Talk-en bidez pasahitza bidaltzea pasahitz berria ezarri gabe",
    "Cannot disable sending the password by Talk without setting a new password" : "Ezin da desgaitu Talk-en bidez pasahitza bidaltzea pasahitz berria ezarri gabe",
    "Share provider does not support accepting" : "Partekatzearen hornitzaileak ez du onarpena onartzen",
    "Cannot change target of link share" : "Ezin da esteka partekatze baten helburua aldatu",
    "Invalid share recipient" : "Partekatze-hartzaile baliogabea",
    "Group \"%s\" does not exist" : "«%s» ez da existitzen",
    "The requested share does not exist anymore" : "Eskatutako partekatzea ez da existitzen dagoeneko",
    "The requested share comes from a disabled user" : "Eskatutako partekatzea desgaitutako erabiltzaile batengatik dator",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
    "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
    "Input text" : "Sartu testua",
    "The input text" : "Sarrerako testua",
    "Sunday" : "Igandea",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sun." : "Ig.",
    "Mon." : "Al.",
    "Tue." : "Ar.",
    "Wed." : "Az.",
    "Thu." : "Og.",
    "Fri." : "Ol.",
    "Sat." : "Lr.",
    "Su" : "Ig",
    "Mo" : "Al",
    "Tu" : "Ar",
    "We" : "Az",
    "Th" : "Og",
    "Fr" : "Ol",
    "Sa" : "Lr",
    "January" : "Urtarrila",
    "February" : "Otsaila",
    "March" : "Martxoa",
    "April" : "Apirila",
    "May" : "Maiatza",
    "June" : "Ekaina",
    "July" : "Uztaila",
    "August" : "Abuztua",
    "September" : "Iraila",
    "October" : "Urria",
    "November" : "Azaroa",
    "December" : "Abendua",
    "Jan." : "Urt.",
    "Feb." : "Ots.",
    "Mar." : "Mar.",
    "Apr." : "Api.",
    "May." : "Mai.",
    "Jun." : "Eka.",
    "Jul." : "Uzt.",
    "Aug." : "Abu.",
    "Sep." : "Ira.",
    "Oct." : "Urr.",
    "Nov." : "Aza.",
    "Dec." : "Abe.",
    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
    "The Login is already being used" : "Saioa dagoeneko erabilita dago",
    "Could not create account" : "Ezin izan da kontua sortu",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira saioan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
    "A valid Login must be provided" : "Baliozko saioa eman behar da",
    "Login contains whitespace at the beginning or at the end" : "Saioak zuriuneren bat du hasieran edo amaieran",
    "Login must not consist of dots only" : "Saioa ezin da puntuz osatuta soilik egon",
    "Login is invalid because files already exist for this user" : "Saioa ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
    "Account disabled" : "Kontua desgaituta",
    "Login canceled by app" : "Aplikazioak saioa bertan behera utzi du",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" aplikazioa ezin da instalatu, menpekotasun hauek betetzen ez direlako:%2$s",
    "a safe home for all your data" : "zure datu guztientzako toki segurua",
    "Application is not enabled" : "Aplikazioa ez dago gaituta",
    "Authentication error" : "Autentifikazio errorea",
    "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ez dago datubaseen (sqlite, mysql edo postgresql) driverrik instalatuta.",
    "Cannot write into \"config\" directory." : "Ezin da \"config\" karpetan idatzi.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari konfigurazio direktoriorako sarbidea emanez. Ikus %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Bestela, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri bertan \"config_is_read_only\" aukerari 'egia' balioa. Ikusi %s",
    "Cannot write into \"apps\" directory." : "Ezin da idatzi \"apps\" fitxategian.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Hau normalean konpondu daiteke web zerbitzariari aplikazioen direktorioko sarbidea emanez edo konfigurazioko fitxategian aplikazioen biltegia (App Store) desgaituz.",
    "Cannot create \"data\" directory." : "Ezin da \"data\" direktorioa sortu.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari root direktorioko idazketa sarbidea emanez. Ikus %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Normalean baimenak konpondu daitezke web zerbitzariari root direktorioko sarbidea emanez. Ikus%s.",
    "Your data directory is not writable." : "Zure datuen karpeta ez da idazgarria.",
    "Setting locale to %s failed." : "Eskualde-ezarpenak %s(e)ra ezartzeak huts egin du",
    "Please install one of these locales on your system and restart your web server." : "Mesedez, instalatu eskualde-ezarpen hauetako bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
    "PHP module %s not installed." : "PHPren %s modulua ez dago instalaturik.",
    "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren administratzaileari modulua instalatzeko.",
    "PHP setting \"%s\" is not set to \"%s\"." : "\"%s\" PHP ezarpena ez dago \"%s\" gisa jarrita.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ezarpen hau php.ini fitxategian doitzen bada, Nextcloud berriro exekutatuko da",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code><code>%s</code>-en ezarrita dago, espero zen <code>0</code> balioaren ordez.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Arazo hau konpontzeko, ezarri<code>mbstring.func_overload</code> <code>0</code>-en zure php.ini fitxategian.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP lerro bakarreko blokeak mozteko konfiguratua dagoela dirudi. Oinarrizko app batzuk eskuraezin bihurtuko dira.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik falta direla jartzen du?",
    "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren administratzaileari web zerbitzaria berrabiarazteko.",
    "The required %s config variable is not configured in the config.php file." : "Beharrezko %s config aldagaia ez dago konfiguratuta config.php fitxategian.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Mesedez, eskatu zure zerbitzari administratzaileari Nextclouden konfigurazioa egiaztatzeko.",
    "Your data directory is readable by other people." : "Zure datuen karpeta beste pertsonek irakur dezakete.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Aldatu baimenak 0770ra beste pertsonak karpeta ikusi ezin izateko.",
    "Your data directory must be an absolute path." : "Zure datuen karpeta bide-izen absolutua izan behar da.",
    "Check the value of \"datadirectory\" in your configuration." : "Egiaztatu \"datadirectory\"-ren balioa zure konfigurazioan.",
    "Your data directory is invalid." : "Zure datuen karpeta baliogabea da.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Ziurtatu datu-direktorioaren erroan  \"%1$s\" izeneko fitxategi bat dagoela.  \"%2$s\" edukia izan behar du.",
    "Action \"%s\" not supported or implemented." : "\"%s\" ekintza ez da onartzen edo ez dago inplementaturik.",
    "Authentication failed, wrong token or provider ID given" : "Autentifikazioak huts egin du, token edo hornitzaile ID okerra eman da",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Eskaera osatzeko parametroak falta dira. Falta diren parametroak: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : " \"%1$s\" IDa dagoeneko erabiltzen du \"%2$s\" hodei federazio hornitzaileak",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Hodei federazio hornitzaile IDa: \"%s\" ez da existitzen.",
    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu %d sarraila mota \"%s\"(e)n.",
    "Storage unauthorized. %s" : "Biltegiratzea ez dago baimenduta. %s",
    "Storage incomplete configuration. %s" : "Biltegiratzea guztiz konfiguratu gabe dago. %s",
    "Storage connection error. %s" : "Biltegiratze-konexioaren errorea. %s",
    "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
    "Storage connection timeout. %s" : "Biltegiratze-konexioa denboraz kanpo geratu da. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Egiaztapen hau exekuta dadin ziurtatu behar duzu zure web zerbitzaria bere buruarekin konektatu daitekeela. Hori dela eta, bere `trusted_domains` edo `overwrite.cli.url`ra gutxienez ebatzi eta konektatzeko gai izan behar du. Baliteke hutsegite hau zerbitzariaren aldeko DNS ez bat etortzea edo irteerako suebakiaren arauaren ondorioa izatea.",
    "Transcribe audio" : "Audioa transkribatu",
    "Transcribe the things said in an audio" : "Audio batean esandako gauzak transkribatu",
    "Audio input" : "Audio sarrera",
    "The audio to transcribe" : "Transkribatzeko audioa",
    "Transcription" : "Transkripzioa",
    "The transcribed text" : "Transkribatutako testua",
    "ContextAgent" : "ContextAgent",
    "Chat with an agent" : "Txateatu agente batekin",
    "Chat message" : "Txat mezua",
    "A chat message to send to the agent." : "Agenteari bidaltzeko txat mezu bat.",
    "Confirmation" : "Berrespena",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Aurretik eskatutako ekintzak berretsi behar diren ala ez: 0 ukatzeko eta 1 berresteko.",
    "Conversation token" : "Elkarrizketa tokena",
    "A token representing the conversation." : "Elkarrizketa adierazten duen token bat.",
    "Generated response" : "Sortutako erantzuna",
    "The response from the chat model." : "Txat modeloaren erantzuna.",
    "The new conversation token" : "Elkarrizketa token berria",
    "Send this along with the next interaction." : "Bidali hau hurrengo interakzioarekin.",
    "Requested actions by the agent" : "Agenteak eskatutako ekintzak",
    "Actions that the agent would like to carry out in JSON format." : "Agenteak egin nahi dituen ekintzak JSON formatuan.",
    "Context write" : "Testuingurua idaztea",
    "Writes text in a given style based on the provided source material." : "Testua estilo jakin batean idazten du, emandako iturri-materialean oinarrituta.",
    "Writing style" : "Idazteko estiloa",
    "Demonstrate a writing style that you would like to immitate" : "Erakutsi imitatu nahiko zenukeen idazteko estiloa",
    "Source material" : "Jatorrizko materiala",
    "The content that would like to be rewritten in the new writing style" : "Idazkera estilo berrian berridatzi nahi den edukia",
    "Generated text" : "Sortutako testua",
    "The generated text with content from the source material in the given style" : "Jatorri-materialaren edukiarekin emandako estiloan sortutako testua.",
    "Emoji generator" : "Emojien sortzailea",
    "Takes text and generates a representative emoji for it." : "Testua hartzen du eta emoji adierazgarri bat sortzen du.",
    "The text to generate an emoji for" : "Emoji bat sortzeko testua",
    "Generated emoji" : "Sortutako emojia",
    "The generated emoji based on the input text" : "Sarrerako testuan oinarrituta sortutako emojia",
    "Generate image" : "Sortu irudia",
    "Generate an image from a text prompt" : "Sortu irudi bat testu-gonbita batetik",
    "Prompt" : "Galdera",
    "Describe the image you want to generate" : "Deskribatu sortu nahi duzun irudia",
    "Number of images" : "Irudi kopurua",
    "How many images to generate" : "Zenbat irudi sortu behar diren",
    "Output images" : "Irteera irudiak",
    "The generated images" : "Sortutako irudiak",
    "Free text to text prompt" : "Testu librea mezuaren testura",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Abisu arbitrario bat exekutatzen du erantzuna itzultzen duen hizkuntza-eredu baten bidez",
    "Describe a task that you want the assistant to do or ask a question" : "Deskribatu laguntzaileak egitea nahi duzun zeregina edo galdera bat egin",
    "Generated reply" : "Sortutako erantzuna",
    "The generated text from the assistant" : "Laguntzaileak sortutako testua",
    "Change Tone" : "Aldatu tonoa",
    "Change the tone of a piece of text." : "Aldatu testu-zati baten tonua.",
    "Write a text that you want the assistant to rewrite in another tone." : "Idatzi laguntzaileak beste tonu batean berridaztea nahi duzun testua.",
    "Desired tone" : "Nahi den tonua",
    "In which tone should your text be rewritten?" : "Ze tonuan berridatzi beharko litzateke zure testua?",
    "The rewritten text in the desired tone, written by the assistant:" : "Berridatzitako testua nahi den tonuan, laguntzaileak idatzita:",
    "Chat" : "Chat",
    "Chat with the assistant" : "Hitz egin txat bidez laguntzailarekin",
    "System prompt" : "Sistemaren gonbita",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Definitu elkarrizketan zehar txat laguntzaileak jarraitu beharko lituzkeen arau eta suposizioak.",
    "Chat history" : "Txat historia",
    "The history of chat messages before the current message, starting with a message by the user" : "Uneko mezuaren aurreko txat mezuen historia, erabiltzailearen mezu batetik hasita",
    "Response message" : "Erantzun mezua",
    "The generated response as part of the conversation" : "Sorturiko erantzuna, elkarrizketaren zati gisa",
    "Chat with tools" : "Txateatu erremintekin",
    "Chat with the language model with tool calling support." : "Txateatu hizkuntza-modeloarekin dei-tresna euskarriarekin.",
    "Tool message" : "Erreminta-mezua",
    "The result of tool calls in the last interaction" : "Tresna-deien emaitza azken interakzioan",
    "Available tools" : "Erreminta erabilgarriak",
    "The available tools in JSON format" : "Erabilgarri dauden erremintak JSON formatuan",
    "The response from the chat model" : "Txat modeloaren erantzuna",
    "Tool calls" : "Erreminta deiak",
    "Tools call instructions from the model in JSON format" : "Tresna-deien argibideak modelotik JSON formatuan",
    "Formalize text" : "Formaldu testua",
    "Takes a text and makes it sound more formal" : "Testu bat hartzen du eta doinu formalagoa ematen dio.",
    "Write a text that you want the assistant to formalize" : "Idatz ezazu laguntzaileak formaltzea nahi duzun testu bat",
    "Formalized text" : "Formaldutako testua",
    "The formalized text" : "Formaldutako testua",
    "Generate a headline" : "Sortu izenburu bat",
    "Generates a possible headline for a text." : "Testu baten izenburu posiblea sortzen du.",
    "Original text" : "Jatorrizko testua",
    "The original text to generate a headline for" : "Izenburu bat sortzeko jatorrizko testua",
    "The generated headline" : "Sortutako izenburua",
    "Proofread" : "Testu-azterketa",
    "Proofreads a text and lists corrections" : "Testu bat aztertzen du eta zuzenketak zerrendatzen ditu",
    "Text" : "Testua",
    "The text to proofread" : "Aztertzeko testua",
    "Corrections" : "Zuzenketak",
    "The corrections that should be made in your text" : "Zure testuan egin behar diren zuzenketak",
    "Reformulate text" : "Birformulatu testua",
    "Takes a text and reformulates it" : "Testu bat hartu eta birformulatu egiten du",
    "Write a text that you want the assistant to reformulate" : "Idatz ezazu laguntzaileak birformulatzea nahi duzun testu bat",
    "Reformulated text" : "Birformulatutako testua",
    "The reformulated text, written by the assistant" : "Birformulaturiko testua, laguntzaileak idatzia",
    "Simplify text" : "Sinpletu testua",
    "Takes a text and simplifies it" : "Testu bat hartu eta sinpletu egiten du",
    "Write a text that you want the assistant to simplify" : "Idatz ezazu laguntzaileak sinpletzea nahi duzun testu bat",
    "Simplified text" : "Sinpletutako testua",
    "The simplified text" : "Sinpletutako testua",
    "Summarize" : "Laburtu",
    "Summarizes a text" : "Laburtu testu bat",
    "The original text to summarize" : "Laburtu beharreko jatorrizko testua",
    "Summary" : "Laburpena",
    "The generated summary" : "Sortutako laburpena",
    "Extract topics" : "Atera gaiak",
    "Extracts topics from a text and outputs them separated by commas" : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu",
    "The original text to extract topics from" : "Gaiak ateratzeko jatorrizko testua",
    "Topics" : "Gaiak",
    "The list of extracted topics" : "Ateratako gaien zerrenda",
    "Translate" : "Itzuli",
    "Translate text from one language to another" : "Itzuli testua hizkuntza batetik bestera",
    "Origin text" : "Jatorrizko testua",
    "The text to translate" : "Itzuli beharreko testua",
    "Origin language" : "Jatorrizko hizkuntza",
    "The language of the origin text" : "Jatorrizko testuaren hizkuntza",
    "Target language" : "Helburuko hizkuntza",
    "The desired language to translate the origin text in" : "Jatorrizko testua itzultzeko nahi den hizkuntza",
    "Result" : "Emaitza",
    "The translated text" : "Itzulitako testua",
    "Free prompt" : "Gonbita librea",
    "Runs an arbitrary prompt through the language model." : "Hizkuntza ereduaren zehar esaldi arbitrario bat exekutatzen du.",
    "Generate headline" : "Sortu izenburua",
    "Summarizes text by reducing its length without losing key information." : "Testua laburtzen du bere luzera murrizten informazio baliotsua galdu gabe.",
    "Extracts topics from a text and outputs them separated by commas." : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu.",
    "Education Edition" : "Hezkuntza edizioa",
    "File name is a reserved word" : "Fitxategi izena hitz erreserbatua da",
    "File name contains at least one invalid character" : "Fitxategi izenak karaktere baliogabe bat du gutxienez ",
    "File name is too long" : "Fitxategi-izena luzeegia da",
    "Users" : "Erabiltzaileak",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du",
    "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
    "Open »%s«" : "Ireki »%s«",
    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
    "File is currently busy, please try again later" : "Fitxategia lanpetuta dago, saiatu berriro geroago",
    "Cannot download file" : "Ezin da fitxategia deskargatu",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ziurtatu datu direktorioaren erroan \".ocdata\" izeneko fitxategia dagoela.",
    "Path contains files shared with you" : "Bide-izenak zurekin partekatutako fitxategiak dauzka"
},
"nplurals=2; plural=(n != 1);");
